from unittest.mock import Mock, ANY

import pytest
from _pytest.monkeypatch import MonkeyPatch
from rasax.community.scheduler import _modify_job

TEST_JOB_ID = "test-job-id"


@pytest.fixture()
def background_job() -> Mock:
    mocked_job = Mock()
    mocked_job.id = TEST_JOB_ID

    return mocked_job


@pytest.mark.freeze_time
def test_modify_job_to_run_immediately(background_job: Mock, monkeypatch: MonkeyPatch):
    job_modification = {"run_immediately": True}

    _modify_job(background_job, job_modification)

    background_job.modify.assert_called_with(next_run_time=ANY, kwargs={})


def test_modify_job_to_not_run_immediately(background_job: Mock):
    job_modification = {"run_immediately": False, "other_argument": 1234}

    _modify_job(background_job, job_modification)

    background_job.modify.assert_called_with(kwargs={"other_argument": 1234})
